import { useCallback, useMemo } from 'react';
import { useObservableState } from '@equinor/fusion-observable/react';
import { useCurrentAppModules } from '../app/useCurrentAppModules';
import { EMPTY, map } from 'rxjs';
import { useFramework } from '../useFramework';
export const useCurrentAppFeatureFlag = (key) => {
    const provider$ = useCurrentAppModules().modules$.pipe(map((val) => val === null || val === void 0 ? void 0 : val.featureFlag));
    const { value: provider } = useObservableState(provider$);
    const { value: feature, error } = useObservableState(_useFeatureFlag(key, provider));
    const setFeatureEnabled = _useSetFeatureflag(provider);
    return { feature, error, setFeatureEnabled };
};
export const useCurrentAppFeatureFlags = () => {
    const provider$ = useCurrentAppModules().modules$.pipe(map((val) => val === null || val === void 0 ? void 0 : val.featureFlag));
    const { value: provider } = useObservableState(provider$);
    const { value: features, error } = useObservableState(_useFeatureFlags(provider));
    const setFeatureEnabled = _useSetFeatureflag(provider);
    return { features, error, setFeatureEnabled };
};
export const useFrameworkFeatureFlag = (key) => {
    const provider = useFramework().modules.featureFlag;
    const { value: feature, error } = useObservableState(_useFeatureFlag(key, provider));
    const setFeatureEnabled = _useSetFeatureflag(provider);
    return { feature, error, setFeatureEnabled };
};
export const useFrameworkFeatureFlags = () => {
    const provider = useFramework().modules.featureFlag;
    const { value: features, error } = useObservableState(_useFeatureFlags(provider));
    const setFeatureEnabled = _useSetFeatureflag(provider);
    return { features, error, setFeatureEnabled };
};
const _useFeatureFlag = (key, provider) => {
    return useMemo(() => {
        return provider ? provider.getFeature(key) : EMPTY;
    }, [provider, key]);
};
const _useFeatureFlags = (provider) => {
    return useMemo(() => {
        return provider ? provider.getFeatures((_) => true) : EMPTY;
    }, [provider]);
};
const _useSetFeatureflag = (provider) => {
    return useCallback((key, enabled) => {
        if (!provider) {
            throw new Error('Missing IFeatureFlagProvider.');
        }
        provider.toggleFeature({ key, enabled });
    }, [provider]);
};
//# sourceMappingURL=useFeatureFlags.js.map